OC.L10N.register(
    "spreed",
    {
    "Talk" : "Talk",
    "Guest" : "Mgeni",
    "Incoming call" : "Muito uanoingia",
    "Message deleted by author" : "Message deleted by author",
    "Message deleted by you" : "Ujumbe umefutwa na wewe",
    "System" : "Mfumo",
    "%s (guest)" : "%s (mgeni)",
    "Talk to %s" : "Talk to %s",
    "File is too big" : "Faili ni kubwa mno",
    "Invalid file provided" : "Faili iliyotolewa si halali",
    "Invalid image" : "Taswira si halisi",
    "Unknown filetype" : "Aina ya faili haijulikani",
    "Say hi to your friends and colleagues!" : "Sema hi kwa marafiki zako na wenzako!",
    "Description" : "Maelezo",
    "Talk conversation for event" : "Mazungumzo ya Talk kwa tukio",
    "Dismiss notification" : "Dismiss notification",
    "Accept" : "Kubali",
    "Decline" : "Kataa",
    "Reminder" : "Kikumbushio",
    "Notification" : "Taarifa",
    "{user} in {call}" : "{user} katika {call}",
    "Join call" : "Jiunge katika muito",
    "You missed a call from {user}" : "Ulikosa simu kutoka {user}",
    "You missed a group call in {call}" : "Ulikosa simu ya kikundi katika {call}",
    "Open settings" : "Mipangilio ya wazi",
    "error" : "hitilafu",
    "Conversations" : "Mazungumzo",
    "Messages" : "Jumbe",
    "{user} in {conversation}" : "{user} katika {conversation}",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Muungano wa Falme za Kiarabu (UAE)",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentina",
    "American Samoa" : "American Samoa",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Visiwa vya Aland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia and Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Ubeligiji",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Switzerland",
    "Cook Islands" : "Visiwa vya Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Visiwa vya Krismas",
    "Cyprus" : "Cyprus",
    "Germany" : "Ujerumani",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominican Republic" : "Jamhuri ya Dominica",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Misri",
    "Eritrea" : "Eritrea",
    "Spain" : "Hispania",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Faroe Islands" : "Visiwa vya Faroe",
    "France" : "Ufaransa",
    "Gabon" : "Gabon",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "French Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Ugiriki",
    "South Georgia and the South Sandwich Islands" : "Georgia Kusini na Visiwa vya Sandwich kusini",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Visiwa vya Heard na McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Iraq",
    "Iceland" : "Iceland",
    "Italy" : "Italia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "Kiribati" : "Kiribati",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Visiwa vya Cayman",
    "Kazakhstan" : "Kazakhstan",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Morocco",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Visiwa vya Marshall",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Visiwa vya Mariana kaskazini",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Kisiwa cha Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Uholanzi",
    "Norway" : "Norway",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "French Polynesia",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Poland",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Ureno",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Visiwa vya Solomon",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Sweden",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan kusini",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "El Salvador",
    "Turks and Caicos Islands" : "Visiwa vya Turks na Caicos",
    "Chad" : "Chad",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Uturuki",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Tuvalu" : "Tuvalu",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Afrika ya kusini",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Shirikisho",
    "Invalid date, date format must be YYYY-MM-DD" : "Tarehe batili, umbizo la tarehe lazima liwe YYYY-MM-DD",
    "Conversation not found" : "Mazungumzo hayapo",
    "Leave call" : "Acha simu",
    "Everyone" : "Kila mmoja",
    "Saving …" : "Inahifadhi...",
    "Saved!" : "Imehifadhiwa",
    "Limit to groups" : "Limit to groups",
    "Enabled" : "Washwa",
    "Disabled" : "Zima",
    "State" : "State",
    "Name" : "Jina",
    "Permissions" : "Ruhusa",
    "Off" : "Imezimwa",
    "Enable encryption" : "Enable encryption",
    "Pending" : "Inasubiri",
    "Error" : "Hitilafu",
    "Active" : "Active",
    "Language" : "Lugha",
    "Country" : "Nchi",
    "Status" : "Wadhifa",
    "Created at" : "Imetengenezwa katika",
    "Shared secret" : "Shared secret",
    "Recording consent" : "Idhini ya kurekodi",
    "Error code" : "Error code",
    "{option1} and {option2}" : "{option1} and {option2}",
    "Failed" : "Imeshindwa",
    "OK" : "OK",
    "Federated user" : "Mtumiaji aliyeshirikishwa",
    "Confirm" : "Thibitisha",
    "Reset" : "Pangilia upya",
    "Back" : "Rudi",
    "Cancel" : "Cancel",
    "Now" : "Sasa",
    "Invite {user}" : "Invite {user}",
    "Loading …" : "Inapakia",
    "From" : "Tangu/ kutoka",
    "To" : "Mpaka/ hadi",
    "Calendar" : "Kalenda",
    "Attendees" : "Wahudhuriaji",
    "Save" : "Hifadhi",
    "No results" : "No results",
    "Done" : "Imefanyika",
    "Raise hand" : "Inua mkono",
    "Lower hand" : "Mkono wa chini",
    "Grid view" : "Grid view",
    "Connecting …" : "Inaunganisha...",
    "Copy link" : "Nakili kiungio",
    "None" : "Hakuna",
    "You" : "Wewe",
    "Collapse" : "Collapse",
    "Expand" : "Expand",
    "Drop your files to upload" : "Dondosha mafaili yako kupakia",
    "Scroll to bottom" : "Scroll to bottom",
    "Public conversation" : "Mazungumzo ya umma",
    "Favorite" : "Kipendwa",
    "Date:" : "Tarehe:",
    "Note:" : "Kumbuka:",
    "Hide details" : "Ficha maelezo",
    "Show details" : "Onesha maelezo",
    "Unban" : "Unban",
    "Disable" : "Zima",
    "Enable" : "Wezesha",
    "Choose" : "Chagua",
    "Restricted" : "Imezuiliwa",
    "Meeting" : "Mkutano",
    "Conversation settings" : "Mipangilio ya mazungumzo",
    "Personal" : "Binafsi",
    "Danger zone" : "Eneo la hatari",
    "Archive conversation" : "Hifadhi mazungumzo",
    "You need to promote a new moderator before you can leave the conversation" : "You need to promote a new moderator before you can leave the conversation",
    "Leave conversation" : "Acha mazungumzo",
    "No" : "Hapana",
    "Yes" : "Ndiyo",
    "Delete conversation" : "Futa mazungumzo",
    "_%n hour_::_%n hours_" : ["%n hour","%n hours"],
    "_%n day_::_%n days_" : ["%n day","%n days"],
    "_%n week_::_%n weeks_" : ["%n week","%n weeks"],
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation.",
    "Guest access" : "Ufikiaji wa mgeni",
    "Password protection" : "Password protection",
    "Set a password" : "Weka nenosiri",
    "Resend invitations" : "Tuma mialiko upya",
    "Lock conversation" : "Funga mazungumzo",
    "Edit" : "Hariri",
    "Delete" : "Futa",
    "Notifications" : "Arifa",
    "Important conversation" : "Mazungumzo muhimu",
    "\"Do not disturb\" user status is ignored for important conversations" : "\"Do not disturb\" user status is ignored for important conversations",
    "Sensitive conversation" : "Mazungumzo nyeti",
    "Message preview will be disabled in conversation list and notifications" : "Message preview will be disabled in conversation list and notifications",
    "Require recording consent before joining call in this conversation" : "Require recording consent before joining call in this conversation",
    "Recording consent is required for all calls" : "Recording consent is required for all calls",
    "Hello, {displayName}" : "Hello, {displayName}",
    "Create a new conversation" : "Tengeneza mazungumzo mapya",
    "Join open conversations" : "Jiunge mazungumzo ya wazi",
    "Unread mentions" : "Mitajo ambayo haijasomwa",
    "Create conversation" : "Tengeneza mazungumzo",
    "Enter your name" : "Enter your name",
    "Log in" : "Ingia",
    "Mark as read" : "Weka alama kama iliyosomwa",
    "Mark as unread" : "Weka alama kama haijasomwa",
    "Remove from favorites" : "Ondoa kutoka katika pendwa",
    "Add to favorites" : "Ongeza kwenye pendwa",
    "Unarchive conversation" : "Unarchive conversation",
    "No pending invitations" : "Hakuna mialiko inayosubiri",
    "Unread" : "Unread",
    "Unread messages" : "Jumbe ambazo hazijasomwa",
    "Clear filter" : "Futa kichujio",
    "Users" : "Watumiaji",
    "Groups" : "Makundi",
    "Teams" : "Timu",
    "Open conversations" : "Mazungumzo ya wazi",
    "No search results" : "Hakuna matokeo ya utafutaji",
    "The meeting will start soon" : "Mkutano utaanza hivi karibuni",
    "This meeting is scheduled for {startTime}" : "Mkutano huu umepangwa kwa {startTime}",
    "Devices" : "Vifaa",
    "The call might be recorded." : "Simu inaweza kuwa imerekodiwa",
    "Invalid path selected" : "Njia iliyochaguliwa si halali",
    "Blur" : "Blur",
    "Upload" : "Pakia",
    "Files" : "Mafaili",
    "Message sent" : "Ujumbe umetumwa",
    "Later today – {timeLocale}" : "Baadaye leo-{timeLocale}",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow – {timeLocale}" : "Kesho-{timeLocale}",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend – {timeLocale}" : "Wikendi-{timeLocale}",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week – {timeLocale}" : "Wiki ijayo-{timeLocale}",
    "Set reminder for next week" : "Set reminder for next week",
    "Edited by {actor}" : "Imehaririwa na {actor}",
    "Reply" : "Jibu",
    "Set reminder" : "Weka ukumbusho",
    "Reply privately" : "Jibu kwa faragha",
    "Edit message" : "Hariri ujumbe",
    "Copy message" : "Copy message",
    "Go to thread" : "Go to thread",
    "Translate" : "Tafsiri",
    "Set custom reminder" : "Set custom reminder",
    "Dismiss" : "Ondoa",
    "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
    "Contact" : "Mawasiliano",
    "{stack} in {board}" : "{stack} katika {board}",
    "Remove {fileName}" : "Remove {fileName}",
    "Poll" : "Kura ya maoni",
    "Today" : "Leo",
    "Yesterday" : "Jana",
    "Add participants" : "Ongeza washiriki",
    "Send message" : "Tuma ujumbe",
    "Send without notification" : "Tuma bila arifa",
    "File to share" : "Faili la kushirikisha",
    "Cancel editing" : "Ghairi uhariri",
    "Share from {nextcloud}" : "Shirikisha kutoka {nextcloud}",
    "Share from Files" : "Shirikisha kutoka katika mafaili",
    "Upload from device" : "Pakia kutoka katika kifaa",
    "Record voice message" : "Rekodi ujumbe wa sauti",
    "End recording and send" : "End recording and send",
    "Dismiss recording" : "Dismiss recording",
    "Error while recording audio" : "Error while recording audio",
    "Talk recording from {time} ({conversation})" : "Talk inarekodi kutoka {time} ({conversation})",
    "Blank" : "Mabano",
    "Send" : "Tuma",
    "Create poll" : "Tengeneza poll",
    "Question" : "Swali",
    "Settings" : "Mipangilio",
    "Multiple answers" : "Majibu mengi",
    "End poll" : "Maliza kura",
    "guest" : "mgeni",
    "Remove group and members" : "Ndoa kundi na wanachama",
    "Remove team and members" : "Ondoa timu na wanachama",
    "Remove participant" : "Ondoa washiriki",
    "Demote from moderator" : "Demote from moderator",
    "Promote to moderator" : "Promote to moderator",
    "Remove" : "Ondoa",
    "Searching …" : "Inatafuta",
    "Participants" : "Washiriki",
    "Details" : "Maelezo ya kina",
    "Shared items" : "Vipengele vilivyoshirikiwa",
    "Search in {name}" : "Tafuta katika {name}",
    "No results found" : "Hakuna matokeo yaliyopatikana",
    "Load more results" : "Pakia matokeo zaidi",
    "Recent threads" : "Recent threads",
    "Projects" : "Projects",
    "No shared items" : "Hakuna vipengele vilivyoshirikiwa",
    "Select conversation" : "Chagua mazungumzo",
    "Appearance" : "Mwonekano",
    "Privacy" : "Faragha",
    "Share my read-status and show the read-status of others" : "Share my read-status and show the read-status of others",
    "Share my typing-status and show the typing-status of others" : "Share my typing-status and show the typing-status of others",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Search" : "Tafuta",
    "More actions" : "Vitendo zaidi",
    "End call" : "Kata simu",
    "End call for everyone" : "Maliza simu kwa kila mtu",
    "Recording" : "Inarekodi",
    "The call has been running for one hour." : "The call has been running for one hour.",
    "Cancel recording start" : "Cancel recording start",
    "Stop recording" : "Simamisha kurekodi",
    "Default" : "Chaguo msingi",
    "Start recording" : "Anza kurekodi",
    "Delete now" : "Futa sasa",
    "Keep" : "Weka",
    "Submit" : "Wasilisha",
    "Local time: {time}" : "Muda wa kawaida: {time}",
    "Search …" : "Tafuta...",
    "Join a conversation or start a new one" : "Jiunge na mazungumzo au anzisha mapya",
    "Talk conversation" : "Mazungumzo ya Talk",
    "User" : "Mtumiaji",
    "Password" : "Nenosiri",
    "Login" : "Ingia",
    "Client ID" : "Kitambulisho cha mteja",
    "Media" : "Midia",
    "Audio" : "Sauti",
    "Other" : "Mengine",
    "Show all files" : "Show all files",
    "Group" : "Kundi",
    "Team" : "Timu",
    "You:" : "Wewe:",
    "You: {lastMessage}" : "Wewe: {lastMessage}",
    "(edited)" : "(imehaririwa)",
    "The recording failed. Please contact your administrator." : "The recording failed. Please contact your administrator.",
    "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
    "{guest} (guest)" : "{guest} (mgeni)",
    "Error while parsing a PROPFIND error" : "Error while parsing a PROPFIND error",
    "Please reload the page." : "Tafadhali pakia ukurasa upya ",
    "Do not disturb" : "Acha kusumbua",
    "Away" : "Mbali",
    "The password is wrong. Try again." : "The password is wrong. Try again.",
    "iOS app" : "Programu ya iOS",
    "__language_name__" : "_lugha_jina_",
    "Call summary (%s)" : "Muhtasari wa simu (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "The call summary bot posts an overview message after the call listing all participants and outlining tasks",
    "Tasks" : "Kazi",
    "Notes" : "Madokezo",
    "Reports" : "Taarifa",
    "Decisions" : "Maamuzi",
    "Agenda" : "Ajenda",
    "Call summary" : "Muhtasari wa simu",
    "Call summary - {title}" : "Muhtasari wa simu-{title}",
    "Call without notification" : "Call without notification",
    "Close" : "Funga"
},
"nplurals=2; plural=(n != 1);");
